pub struct MoonState {
pub longitude_degrees: f64,
pub latitude_degrees: f64,
pub distance_km: f64,
pub ra_degrees: f64,
pub dec_degrees: f64,
}Expand description
Apparent geocentric position of the Moon at a Julian Ephemeris Day (TT): ELP/MPP02 geometric place, precessed to the ecliptic of date and corrected for nutation in longitude, then resolved to equatorial coordinates.
Fields
longitude_degrees: f64Apparent ecliptic longitude of date, degrees [0, 360).
latitude_degrees: f64Ecliptic latitude, degrees.
distance_km: f64Geocentric distance, kilometres.
ra_degrees: f64Apparent right ascension, degrees [0, 360).
dec_degrees: f64Apparent declination, degrees.